package de.fraunhofer.iem.dataprovider.taskManager.tasks.tools.detekt

import de.fraunhofer.iem.dataprovider.taskManager.events.Event
import de.fraunhofer.iem.dataprovider.taskManager.tasks.tools.sarif.SarifTask
import de.fraunhofer.iem.dataprovider.toolRun.service.ToolRunService
import org.springframework.core.io.ClassPathResource
import org.springframework.core.io.Resource
import java.io.File
import java.nio.file.Files
import java.nio.file.Path
import java.nio.file.Paths
import java.util.*


class DetektTask(
    repositoryDirectoryPath: String,
    outputDirectoryPath: String,
    override val responseChannel: suspend (task: Event) -> Unit,
    override val repoId: UUID,
    override val groupID: UUID? = null,
    override val toolRunService: ToolRunService
) : SarifTask() {

    private val resource: Resource = ClassPathResource("scripts/detekt.sh")
    override val outputDirectory = Paths.get(outputDirectoryPath, "detekt", taskID.toString()).toString()
    override val resultFileOutputPath: Path = Paths.get(outputDirectory, "report.sarif")
    private val copiedRepositoryPath = Paths.get(outputDirectory, "copiedRepo")

    override val flags: Array<String> = arrayOf(resource.file.absolutePath, repositoryDirectoryPath, outputDirectory)

    override fun cleanUp() {
        File(copiedRepositoryPath.toUri()).deleteRecursively()
    }

    init {
        val repoFile = File(repositoryDirectoryPath)
        val copiedRepo = File(copiedRepositoryPath.toUri())
        repoFile.copyRecursively(copiedRepo)
        Files.createDirectories(Paths.get(outputDirectory))
    }
}
