package de.fraunhofer.iem.dataprovider.taskManager.tasks.tools.ort

import de.fraunhofer.iem.dataprovider.dependency.dto.DependencyCreateDto
import de.fraunhofer.iem.dataprovider.taskManager.events.Event
import de.fraunhofer.iem.dataprovider.taskManager.events.OrtAnalyzerDoneEvent
import de.fraunhofer.iem.dataprovider.taskManager.tasks.tools.ToolProcessTask
import org.springframework.core.io.ClassPathResource
import org.springframework.core.io.Resource
import java.io.File
import java.nio.file.Path
import java.nio.file.Paths
import java.util.*

class OrtAnalyzerTask(
    repositoryDirectoryPath: String,
    outputDirectoryPath: String,
    override val responseChannel: suspend (event: Event) -> Unit,
    override val repoId: UUID,
    override val groupID: UUID? = null
) : ToolProcessTask<List<DependencyCreateDto>>() {

    private val resource: Resource = ClassPathResource("scripts/ort/ort_analyzer.sh")
    override val outputDirectory = Paths.get(outputDirectoryPath, "ort-analyzer", taskID.toString()).toString()
    override val resultFileOutputPath: Path = Paths.get(outputDirectory, "analyzer-result.json")
    private val copiedRepositoryPath = Paths.get(outputDirectory, "copiedRepo")

    override val flags = arrayOf(resource.file.absolutePath, copiedRepositoryPath.toString(), outputDirectory)

    override suspend fun parseProcessResults(resultPath: Path): List<DependencyCreateDto> {
        return emptyList()
    }

    override suspend fun storeResultsInDb(result: List<DependencyCreateDto>) {
    }

    override suspend fun handleProcessReturn(p: Process) {
        responseChannel(OrtAnalyzerDoneEvent(outputDirectory, repoId, taskID, groupID))
    }

    override fun cleanUp() {
        File(copiedRepositoryPath.toUri()).deleteRecursively()
    }

    init {
        val repoFile = File(repositoryDirectoryPath)
        val copiedRepo = File(copiedRepositoryPath.toUri())
        repoFile.copyRecursively(copiedRepo)
    }

}