package de.fraunhofer.iem.dataprovider.taskManager.tasks.tools.qodana

import de.fraunhofer.iem.dataprovider.taskManager.events.Event
import de.fraunhofer.iem.dataprovider.taskManager.tasks.tools.qodana.json.getQodanaSarifFromFilePath
import de.fraunhofer.iem.dataprovider.taskManager.tasks.tools.sarif.SarifTask
import de.fraunhofer.iem.dataprovider.toolRun.service.ToolRunService
import org.springframework.core.io.ClassPathResource
import org.springframework.core.io.Resource
import java.io.File
import java.nio.file.Path
import java.nio.file.Paths
import java.util.*


class QodanaTask(
    repositoryDirectoryPath: String,
    outputDirectoryPath: String,
    override val responseChannel: suspend (task: Event) -> Unit,
    override val repoId: UUID,
    override val groupID: UUID? = null,
    override val toolRunService: ToolRunService
) : SarifTask() {

    private val resource: Resource = ClassPathResource("scripts/qodana.sh")
    override val outputDirectory = Paths.get(outputDirectoryPath, "qodana", taskID.toString()).toString()
    private val copiedRepositoryPath = Paths.get(outputDirectory, "copiedRepo")

    override val flags: Array<String> =
        arrayOf(resource.file.absolutePath, copiedRepositoryPath.toString(), outputDirectory)

    override val resultFileOutputPath: Path = Paths.get(outputDirectory, "qodana.sarif.json")

    override val getSarif = ::getQodanaSarifFromFilePath

    override fun cleanUp() {
        File(copiedRepositoryPath.toUri()).deleteRecursively()
    }

    init {
        val repoFile = File(repositoryDirectoryPath)
        val copiedRepo = File(copiedRepositoryPath.toUri())
        repoFile.copyRecursively(copiedRepo)
    }
}